@@ -3,7 +3,7 @@
 
 This Python package computes the position and velocity of an
 earth-orbiting satellite, given the satellite's TLE orbital elements
-from a source like `Celestrak <https://celestrak.com/>`_.  It implements
+from a source like `CelesTrak <https://celestrak.com/>`_.  It implements
 the most recent version of SGP4, and is regularly run against the SGP4
 test suite to make sure that its satellite position predictions **agree
 to within 0.1 mm** with the predictions of the standard distribution of
@@ -118,7 +118,10 @@ will soon run out of satellite numbers.
   convention and should return the correct integer in Python.
 
 * Some authorities are now distributing satellite elements in an “OMM”
-  Orbit Mean Elements Message format that replaces the TLE format.
+  Orbit Mean Elements Message format that replaces the TLE format.  You
+  can learn about OMM in Dr. T.S. Kelso’s `“A New Way to Obtain GP Data”
+  <https://celestrak.com/NORAD/documentation/gp-data-formats.php>`_ at
+  the CelesTrak site.
 
 You can already try out experimental support for OMM:
 
@@ -144,6 +147,9 @@ Or, to load OMM from CSV:
 Either way, the satellite object should wind up properly initialized and
 ready to start producing positions.
 
+If you are interested in saving satellite parameters using the new OMM
+format, then read the section on “Export” below.
+
 Epoch
 -----
 
@@ -268,7 +274,10 @@ Attributes
 ----------
 
 The attributes of a ``Satrec`` object carry the data loaded from the TLE
-entry.  Look at the class's documentation for details.
+entry.  [INSERT CLASS DOCSTRING HERE.]
+
+The parameters are also listed briefly, along with their units, in the
+“Providing your own elements” section below.
 
 Export
 ------
@@ -276,13 +285,41 @@ Export
 If you have a ``Satrec`` you want to share with friends or persist to a
 file, there’s an export routine that will turn it back into a TLE:
 
->>> from sgp4.exporter import export_tle
->>> line1, line2 = export_tle(satellite)
+>>> from sgp4 import exporter
+>>> line1, line2 = exporter.export_tle(satellite)
 >>> line1
 '1 25544U 98067A   19343.69339541  .00001764  00000-0  38792-4 0  9991'
 >>> line2
 '2 25544  51.6439 211.2001 0007417  17.6667  85.6398 15.50103472202482'
 
+And another that produces the fields defined by the new OMM format (see
+the “OMM” section above):
+
+>>> from pprint import pprint
+>>> fields = exporter.export_omm(satellite, 'ISS (ZARYA)')
+>>> pprint(fields)
+{'ARG_OF_PERICENTER': 17.6667,
+ 'BSTAR': 3.8792e-05,
+ 'CENTER_NAME': 'EARTH',
+ 'CLASSIFICATION_TYPE': 'U',
+ 'ECCENTRICITY': 0.0007417,
+ 'ELEMENT_SET_NO': 999,
+ 'EPHEMERIS_TYPE': 0,
+ 'EPOCH': '2019-12-09T16:38:29.363423',
+ 'INCLINATION': 51.6439,
+ 'MEAN_ANOMALY': 85.6398,
+ 'MEAN_ELEMENT_THEORY': 'SGP4',
+ 'MEAN_MOTION': 15.501034720000002,
+ 'MEAN_MOTION_DDOT': 0.0,
+ 'MEAN_MOTION_DOT': 1.764e-05,
+ 'NORAD_CAT_ID': 25544,
+ 'OBJECT_ID': '1998-067A',
+ 'OBJECT_NAME': 'ISS (ZARYA)',
+ 'RA_OF_ASC_NODE': 211.2001,
+ 'REF_FRAME': 'TEME',
+ 'REV_AT_EPOCH': 20248,
+ 'TIME_SYSTEM': 'UTC'}
+
 Gravity
 -------
 
@@ -318,8 +355,8 @@ satellite object to reset it to those new elements.
 ...     5,               # satnum: Satellite number
 ...     18441.785,       # epoch: days since 1949 December 31 00:00 UT
 ...     2.8098e-05,      # bstar: drag coefficient (/earth radii)
-...     6.969196665e-13, # ndot: ballistic coefficient (revs/day)
-...     0.0,             # nddot: second derivative of mean motion (revs/day^3)
+...     6.969196665e-13, # ndot (NOT USED): ballistic coefficient (revs/day)
+...     0.0,             # nddot (NOT USED): mean motion 2nd derivative (revs/day^3)
 ...     0.1859667,       # ecco: eccentricity
 ...     5.7904160274885, # argpo: argument of perigee (radians)
 ...     0.5980929187319, # inclo: inclination (radians)
@@ -328,8 +365,14 @@ satellite object to reset it to those new elements.
 ...     6.0863854713832, # nodeo: right ascension of ascending node (radians)
 ... )
 
-To compute the “epoch” value, simply take a normal Julian date and
-subtract ``2433281.5`` days.
+The two parameters marked “NOT USED” above, ``ndot`` and ``nddot``, do
+get saved to the satellite object, and do get written out if you write
+the parameters to a TLE or OMM file.  But they are ignored by SGP4 when
+doing propagation, so you can leave them ``0.0`` without any effect on
+the resulting satellite positions.
+
+To compute the “epoch” value, you can simply take a normal Julian date
+and subtract ``2433281.5`` days.
 
 In addition to setting the attributes natively set by the underlying
 ``sgp4init()`` routine, this library also goes ahead and sets the date
@@ -390,6 +433,8 @@ https://pypi.org/project/sgp4/1.4/
 Changelog
 ---------
 
+| 2021-02-12 — 2.16 — Fixed ``days2mdhms()`` rounding to always match TLE epoch.
+| 2021-01-08 — 2.15 — Fixed parsing of the ``satnum`` TLE field in the Python fallback code, when the field has a leading space; added OMM export routine.
 | 2020-12-16 — 2.14 — New data formats: added OMM message support for both XML and CSV, and added support for the new Alpha-5 extension to TLE files.
 | 2020-10-14 — 2.13 — Enhanced ``sgp4init()`` with custom code that also sets the ``epochdays`` and ``epochyr`` satellite attributes.
 | 2020-05-28 — 2.12 — Moved the decision of whether to set the locale during ``twoline2rv()`` from import time to runtime, for users who change locales after their application is up and running.
